@@ -23,7 +23,7 @@ if __name__ == "__main__":
     # configure logger
     logging.basicConfig()
     dateTimeTag = datetime.datetime.now().strftime( '%Y-%m-%d_%H%M%S' )
-    outDataDirPath = 'data/python_' + dateTimeTag
+    outDataDirPath = 'data/location_' + dateTimeTag
  
     rc = batchRunner.runBatch(
         frameProcessor = pythonFrameProcessor(),
